Index: chrome/browser/renderer_host/render_view_host_delegate.h |
=================================================================== |
--- chrome/browser/renderer_host/render_view_host_delegate.h (revision 17020) |
+++ chrome/browser/renderer_host/render_view_host_delegate.h (working copy) |
@@ -421,10 +421,10 @@ |
int32 page_id, |
const webkit_glue::WebApplicationInfo& app_info) { } |
// Notification the user has pressed enter or space while focus was on the |
// page. This is used to avoid uninitiated user downloads (aka carpet |
// bombing), see DownloadRequestManager for details. |
- virtual void OnEnterOrSpace() { } |
+ virtual void OnUserGesture() { } |
// If this view is used to host an external tab container. |
virtual bool IsExternalTabContainer() const { return false; } |
@@ -421,10 +421,10 @@ |
int32 page_id, |
const webkit_glue::WebApplicationInfo& app_info) { } |
- // Notification the user has pressed enter or space while focus was on the |
+ // Notification the user has made a gesture while focus was on the |
// page. This is used to avoid uninitiated user downloads (aka carpet |
// bombing), see DownloadRequestManager for details. |